==> libgphoto2_2.5.27.orig.tar.xz: libgphoto2-2.5.27/camlibs/polaroid/jd350e_red.h <==
/* jd350e_red.h
 *
 * White balancing curve for daylight images (experimental)
 *
 * Copyright 2001 Michael Trawny <trawny99@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

 static unsigned jd350e_red_curve [] = {
  0, 1, 2, 3,
  4, 5, 6, 8,
  9, 10, 11, 12,
  13, 15, 16, 17,
  18, 19, 20, 21,
  23, 24, 25, 25,
  26, 28, 31, 33,
  36, 39, 41, 43,
  45, 48, 50, 52,
  55, 57, 60, 62,
  64, 66, 69, 72,
  73, 75, 78, 80,
  81, 83, 86, 88,
  89, 90, 92, 97,
  98, 101, 107, 108,
  111, 114, 115, 117,
  119, 120, 121, 122,
  123, 127, 129, 133,
  132, 136, 137, 144,
  145, 147, 150, 153,
  154, 157, 158, 161,
  164, 167, 168, 170,
  172, 176, 178, 180,
  183, 184, 186, 190,
  191, 194, 193, 197,
  199, 201, 201, 207,
  206, 210, 211, 215,
  217, 219, 219, 221,
  225, 231, 231, 232,
  235, 235, 236, 242,
  243, 244, 245, 247,
  247, 250, 250, 251,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 255};

==> libgphoto2_2.5.33.orig.tar.xz: libgphoto2-2.5.33/camlibs/polaroid/jd350e_red.h <==
#ifndef CAMLIBS_POLAROID_JD350E_RED_H
#define CAMLIBS_POLAROID_JD350E_RED_H

/* jd350e_red.h
 *
 * White balancing curve for daylight images (experimental)
 *
 * Copyright 2001 Michael Trawny <trawny99@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

 static unsigned jd350e_red_curve [] = {
  0, 1, 2, 3,
  4, 5, 6, 8,
  9, 10, 11, 12,
  13, 15, 16, 17,
  18, 19, 20, 21,
  23, 24, 25, 25,
  26, 28, 31, 33,
  36, 39, 41, 43,
  45, 48, 50, 52,
  55, 57, 60, 62,
  64, 66, 69, 72,
  73, 75, 78, 80,
  81, 83, 86, 88,
  89, 90, 92, 97,
  98, 101, 107, 108,
  111, 114, 115, 117,
  119, 120, 121, 122,
  123, 127, 129, 133,
  132, 136, 137, 144,
  145, 147, 150, 153,
  154, 157, 158, 161,
  164, 167, 168, 170,
  172, 176, 178, 180,
  183, 184, 186, 190,
  191, 194, 193, 197,
  199, 201, 201, 207,
  206, 210, 211, 215,
  217, 219, 219, 221,
  225, 231, 231, 232,
  235, 235, 236, 242,
  243, 244, 245, 247,
  247, 250, 250, 251,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 250, 250,
  250, 250, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 251,
  251, 251, 251, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 252, 252, 252,
  252, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 253, 253,
  253, 253, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 254,
  254, 254, 254, 255};

#endif /* !defined(CAMLIBS_POLAROID_JD350E_RED_H) */
